# Tutorials

These tutorials relate to the version of AllenNLP at the git commit SHA you are currently looking at (likely the HEAD commit of the master branch).  If you want to see the tutorials that relate to the latest pip release, please see https://github.com/allenai/allennlp/tree/v0.4.0/tutorials.

## Getting Started

* [Installation](getting_started/installation.md)
* [Training and Evaluating Models](getting_started/training_and_evaluating.md)
* [Configuring Experiments](getting_started/configuration.md)
* [Creating a Model](getting_started/creating_a_model.md)
* [Using AllenNLP in Your Project](getting_started/using_in_your_repo.md)
* [Making Predictions and Creating a Demo](getting_started/making_predictions_and_creating_a_demo.md)
* [Laziness in AllenNLP](getting_started/laziness.md)

## How-to

* [Using span representations](how_to/span_representations.md)
* [Using pre-trained ELMo representations](how_to/elmo.md)
* [How to train a model with lazy data](how_to/laziness.md)
* [How to visualize model internals (BETA)](how_to/visualizing_model_internals.md)

## Deeper Dives

* [Datasets, Instances, and Fields](notebooks/data_pipeline.ipynb)
* [Vocabularies](notebooks/vocabulary.ipynb)
